Stan Math Library: stan/math/rev/core/chainablestack.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

chainablestack.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_CORE_CHAINABLESTACK_HPP
2 #define STAN_MATH_REV_CORE_CHAINABLESTACK_HPP
3
4 #include <stan/math/rev/core/autodiffstackstorage.hpp>
5
6 namespace stan {
7 namespace math {
8
9 class vari;
10 class chainable_alloc;
11
12 typedef AutodiffStackStorage<vari, chainable_alloc> ChainableStack;
13
14 }
15 }
16 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::AutodiffStackStorage
Definition: autodiffstackstorage.hpp:12
stan::math::chainable_alloc
A chainable_alloc is an object which is constructed and destructed normally but the memory lifespan i...
Definition: chainable_alloc.hpp:16
stan::math::ChainableStack
AutodiffStackStorage< vari, chainable_alloc > ChainableStack
Definition: chainablestack.hpp:10
autodiffstackstorage.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.